var SIEVE = {
    "version": 20200828,
    "rules": [
        {
            "site": "reddit",
            "srcPattern": /(.*)\/\/preview\.redd\.it\/(.*)\.(.*)/,
            replace: function(src) {
                return src.replace(/preview/, "i").replace(/\?(.*)/, "")
            }
        },
        {
            "site": "imgur",
            "srcPattern": /(.*)i\.imgur\.com\/(.*)/,
            replace: function(src) {
                return src.replace(/\?(.*)/, "?maxwidth=99999")
            }
        },
        {
            "site": "twitter",
            "srcPattern": /(.*)twimg.com(.*)name=(.*)/,
            replace: function (src) {
                return src.replace(/name=(.*)/, "name=orig")
            }
        },
        {
            "site": "花瓣网",
            "srcPattern": "//hbimg[.]*/*",
            replace: function (str) {
            	return str.split('/format/')[0].replace(/_sq235$/, '').replace(/_sq75$/, '').replace(/_fw[\d]+[w]*$/, '').split("_fw")[0].split('/fw/')[0];
            }
        },
        {
            "site": "Dribbble",
            "srcPattern": "https?://cdn.dribbble.com/*",
            replace: function (src) {
                if (src.indexOf("/attachments/") === -1) {
            	   return src.replace(/_1x/g, '').replace(/_teaser/g, '')
                }
                else {
                    return src;
                }
        	}
        },
        {
            "site": "新浪微博",
            "srcPattern": "https?://.*[.]sinaimg[.]cn/.*",
            replace: function (src) {
            	return src.replace(/[/]small[/]/, '/large/').replace(/[/]square[/]/, '/large/').replace(/[/]thumbnail[/]/, '/large/').replace(/[/]bmiddle[/]/, '/large/').replace(/[/]thumb[\d]*[/]/, '/large/').replace(/[/]mw[\d]+[/]/, '/large/')
        	}
        },
        {
            "site": "QQ相册/空间",
            "srcPattern": "https?://.*[.]photo[.]store[.]qq[.]com/.*",
            replace: function (src) {
            	return src.replace(/[/]m[/]/, '/o/').replace(/&w=[\d]+&h=[\d]+/, '')
        	}
        },
        {
            "site": "QQ相册2",
            "srcPattern": "https?://group[.]store[.]qq[.]com/.*",
            replace: function (src) {
            	return src.replace(/[/]400$/, '/800').replace(/[/]200$/, '/800').replace(/[/]100$/, '/800')
        	}
        },
        {
            "site": "百度贴吧",
            "srcPattern": "https?://tiebapic[.]baidu[.]com/forum.*",
            replace: function (src) {
                var reg = /^(http:\/\/tiebapic\.baidu\.com\/forum\/)ab(pic\/item\/[\w.]+)/i;
                var portrait = /\/sys\/portrait/;
                var result = src.match(reg);
                if (portrait.test(src)) {
                    return src.replace(/\/sys\/portrait/, "/sys/portraitl");
                } else if (result) { //小图的时候
                    return result[1] + result[2];
                } else { //小图点击之后的较大图，或者帖子内容页面的图片。
                    var prefix = 'http://tiebapic.baidu.com/forum/pic/item/';
                    var reg2 = /\/sign=\w+\/([\w.]+)$/;
                    var sign = src.match(reg2);
                    return sign ? prefix + sign[1] : null;
                };
            }
        },
        {
            "site": "百度图趣",
            "srcPattern": "https?://hiphotos[.]baidu[.]com/.*",
            replace: function (src) {
            	return src.replace(/[/]abpic[/]/, '/pic/').replace(/[/]pin[/]w=[\d]+[/].+[/]/, '/pin/pic/item/')
        	}
        },
        {
            "site": "豆瓣相册",
            "srcPattern": "https?://img[\d]*[.]doubanio[.]com/.*",
            replace: function (src) {
            	return src.replace(/[/]m[/]/, '/l/').replace(/[/]sqs[/]/, '/l/')
        	}
        },
        {
            "site": "Flickr",
            "srcPattern": ".*[.]staticflickr[.]com.*",
            replace: function (src) {
            	return src.replace(/_[nms]\.jpg$/, '_b.jpg')
        	}
        },
        {
            "site": "poco.cn",
            "srcPattern": "http?://img[\d].*pocoimg*",
            replace: function (src) {
            	return src.replace(/_\d{3}.jpg$/, '.jpg')
        	}
        },
        {
            "site": "蘑菇街",
            "srcPattern": "https?://.*[.]mogucdn[.]com/.*.jpg",
            replace: function (src) {
            	return src.replace(/_[\d]{3}x[\d]+.jpg$/, '_468x468.jpg').split('.jpg')[0] + '.jpg'
        	}
        },
        {
            "site": "pinterest",
            "srcPattern": "https?://.*[.]pinimg[.]com/.*.jpg",
            replace: function (src) {
            	return src.replace(/[0-9]+x/g, '736x')
        	}
        },
        {
            "site": "1688",
            "srcPattern": "https?://cbu01.alicdn.com/img/ibank/.*\..*x.*\.jpg",
            replace: function (src) {
            	return src.replace(/\.\d+x.*\./, '.')
        	}
        },
        {
            "site": "淘宝",
            "srcPattern": /.(?:taobao|tb|ali)cdn(.+)_\d+x\d+.jpg(.*)/,
            replace: function(src) {
                return src.replace(/_\d+x\d+.jpg(_.webp)?/, '')
            }
        }, {
            "site": "天猫",
            "srcPattern": /.(?:taobao|tb|ali)cdn(.+)_\d+x\d+\S\d+.jpg(.*)/,
            replace: function(src) {
                return src.replace(/_\d+x\d+\S\d+.jpg(_.webp)?/, '')
            }
        },
        {
            "site": "京东",
            "srcPattern": "https://.*.360buyimg.com.*",
            replace: function(src) {
                return src.replace(/\/n\d+\//, '/n0/').replace(/s\d+x\d+_?/, '').split("!cc")[0].split("!q")[0];
            }
        },
        {
            "site": "Houzz",
            "srcPattern": "https://st[.]hzcdn[.]com/.*",
            replace: function (src) {
            	return src.replace(/fimgs/,'simgs').replace(/_/,'_14-')
        	}
        },
        {
            "site": "HouseBeautiful",
            "srcPattern": "https://hips[.]hearstapps[.]com/.*",
            replace: function (src) {
            	return src.replace(/[.]jpg{1,}/,'.jpg').split('&resize=')[0]
        	}
        },
        {
            "site": "Officesnapshots",
            "srcPattern": "https://officesnapshots[.]com/.*",
            replace: function (src) {
            	return src.replace(/-\d{3,4}x\d{3,4}/,'')
        	}
        },
        {
            "site": "Archilovers",
            "srcPattern": "https?://img[.]archilovers[.]com/.*",
            replace: function (src) {
            	return src.replace(/[a-z]_[0-9][0-9][0-9]_/,'').split('?w=')[0]
        	}
        },
        {
            "site": "AD",
            "srcPattern": "https://media[.]architecturaldigest[.]com/.*",
            replace: function (src) {
            	return src.replace(/w_\d+/,'w_5000').replace(/,h_\d+/,'')
        	}
        },
        {
            "site": "Archdaily 中文版",
            "srcPattern": "http://images[.]adsttc[.]com[.]qtlcn[.]com/.*",
            replace: function (src) {
            	return src.replace(/thumb_/,'large_').replace('/medium_jpg/', '/large_jpg/').replace('/newsletter/', '/large_jpg/')
        	}
        },
        {
            "site": "ArchDaily 国际版",
            "srcPattern": "https://images[.]adsttc[.]com/.*",
            replace: function (src) {
            	return src.replace(/slideshow/,'large_jpg').replace(/thumb_jpg/,'large_jpg').replace('/medium_jpg/', '/large_jpg/').replace('/newsletter/', '/large_jpg/')
        	}
        },
        {
            "site": "Dezeen",
            "srcPattern": "https://static[.]dezeen[.]com/.*",
            replace: function (src) {
            	return src.replace(/slideshow/,'large_jpg').replace(/thumb_jpg/,'large_jpg').replace(/-\d+x\d+.jpg/,'.jpg')
        	}
        },
        {
            "site": "Archiproducts",
            "srcPattern": "https://img[.]edilportale[.]com/.*",
            replace: function (src) {
            	return src.replace(/-thumbs.*.[a-z]_/,'s/').replace(/news.*.[a-z]_/,'news/')
        	}
        },
        {
            "site": "Wordpress 通用",
            "srcPattern": "/wp-content/uploads/.*",
            replace: function (src) {
            	return src.replace(/-\d+x\d+/,'').split('?w=')[0]
        	}
        },
        {
            "site": "Squarespace 通用",
            "srcPattern": "https://static[0-9][.]squarespace[.]com/.*",
            replace: function (src) {
            	return src.replace(/format=[0-9]{3,4}w/,'format=3000w')
        	}
        },
        {
            "site": "站酷",
            "srcPattern": "https://img[.]zcool[.]cn/.*",
            replace: function (src) {
            	return src.replace(/[.]jpg+[.]jpg/,'.jpg').replace(/@\d{1,4}w.*/, '')
        	}
        },
        {
            "site": "Medium",
            "srcPattern": "https://cdn-images-[0-9][.]medium[.]com/.*",
            replace: function (src) {
            	return src.replace(/\/max\/\d{2,4}/, '')
        	}
        },
        {
            "site": "Artstation",
            "srcPattern": "https://cdn.*.artstation.com.*",
            replace: function (src) {
            	return src.replace(/\d{14}\/small_square/, 'large').replace(/\d{14}\/smaller_square/, 'large').replace(/\d{14}\/micro_square/, 'large').replace(/\/smaller_square/, '/large')
        	}
        },
        {
            "site": "interiordesign",
            "srcPattern": "https://d4qwptktddc5f[.]cloudfront[.]net/.*",
            replace: function (src) {
            	return src.replace(/easy_thumbnails\/thumbs_/,'').replace(/[.]jpg.*/,'.jpg')
        	}
        },
        {
            "site": "即刻",
            "srcPattern": "https://cdn[.]ruguoapp[.]com/.*",
            replace: function (src) {
            	return src.split('?imageMogr2')[0]
        	}
        }
    ]
}